@@ -118,7 +118,12 @@ get_passwd(void)
     }
     ldm.password[t] = '\0';
     g_free(prompt);
-    set_message(_("<b>Verifying password.  Please wait.</b>"));
+
+    gchar * verify_password_msg;
+    verify_password_msg=g_strconcat("<b>", _("Verifying password.  Please wait."), "</b>", NULL);
+    set_message(verify_password_msg);
+    g_free(verify_password_msg);
+
     return 0;
 }
 
