@@ -287,7 +287,6 @@ void
 x_session(void)
 {
     gchar *command;
-    get_Xsession();
 
     setenv("LDM_SESSION", ldm.session, 1);
     setenv("LDM_XSESSION", ldm.xsession, 1);
@@ -513,12 +512,31 @@ main(int argc, char *argv[])
     if (!ldm.session) {
         ldm.session = g_strdup("default");
     }
-
     if (err_msg) {
         loginfo("%s", err_msg);
         die(_("Fatal error, missing mandatory information"));
     }
 
+    /* Get the Xsession information from ldminfod before 
+       we potentially change the IP (when using LTSP-Cluster) */
+    get_Xsession();
+
+    /* Check for LTSP-Cluster, if true, contact the loadbalancer for an IP */
+    if (access("/etc/ltsp/getltscfg-cluster.conf", F_OK) == 0) {
+        FILE *fp;
+        fp = popen("getltscfg-cluster -l ldm", "r");
+        if (fp != NULL) {
+            loginfo("IP before balancing: %s",ldm.server);
+            if (fgets(ldm.server, PATH_MAX, fp) == NULL) {
+                loginfo("Balancing failed to get an IP");
+            }
+            loginfo("IP after balancing: %s",ldm.server);
+        }
+        if (pclose(fp) == -1) {
+            logerr("Balancing failed");
+        }
+    }
+
     /*
      * If we run multiple ldm sessions on multiply vty's we need separate
      * control sockets.
