@@ -22,12 +22,14 @@ struct ldm_info {
     gboolean sound;
     gboolean localdev;
     gboolean directx;
+    gboolean nomad;
     gint     sshfd;
     gint     sshslavefd;
     GIOChannel *greeterr;
     GIOChannel *greeterw;
     GPid     pid;
     GPid     sshpid;
+    GPid     nomadpid;
     GPid     xsessionpid;
     GPid     greeterpid;
 };
@@ -42,6 +44,7 @@ int get_passwd();
 int get_language();
 int get_host();
 int get_session();
+void *eater(void);
 void ssh_session(void);
 void ssh_endsession(void);
 void close_greeter(void);
